@@ -29,6 +29,7 @@ class Project:
     TEMPLATE_FILTERS = {"snakecase": utils.snake_case, "kebabcase": utils.kebab_case}
     project_name_override: Optional[str] = None
     package_name_override: Optional[str] = None
+    package_version_override: Optional[str] = None
 
     def __init__(self, *, openapi: GeneratorData) -> None:
         self.openapi: GeneratorData = openapi
@@ -42,7 +43,7 @@ class Project:
         self.package_description: str = utils.remove_string_escapes(
             f"A client library for accessing {self.openapi.title}"
         )
-        self.version: str = openapi.version
+        self.version: str = self.package_version_override or openapi.version
 
         self.env.filters.update(self.TEMPLATE_FILTERS)
 
@@ -76,7 +77,7 @@ class Project:
 
     def _reformat(self) -> None:
         subprocess.run(
-            "autoflake -i -r --remove-all-unused-imports --remove-unused-variables .",
+            "autoflake -i -r --remove-all-unused-imports --remove-unused-variables --ignore-init-module-imports .",
             cwd=self.package_dir,
             shell=True,
             stdout=subprocess.PIPE,
